==> kdenetwork-3.3.2.tar.bz2: kdenetwork-3.3.2/kopete/protocols/irc/irctransferhandler.h <==
/*
    irctransferhandler.h - IRC transfer.

    Copyright (c) 2003      by Michel Hermier <michel.hermier@wanadoo.fr>

    Kopete    (c) 2003      by the Kopete developers <kopete-devel@kde.org>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef IRCTRANSFERHANDLER_H
#define IRCTRANSFERHANDLER_H

#include <qintdict.h>

#include <kopetetransfermanager.h>

class KopeteTransfer;

class KIRCTransfer;
class KIRCTransferHandler;

class IRCTransferHandler
	: public QObject
{
	Q_OBJECT

public:
	static IRCTransferHandler *self();

private slots:
	void transferCreated(KIRCTransfer *);
	void transferAccepted(KopeteTransfer *kt, const QString&file);
	void transferRefused(const KopeteFileTransferInfo &info);

	void kioresult(KIO::Job *job);

private:
	IRCTransferHandler();

	void connectKopeteTransfer(KopeteTransfer *kt, KIRCTransfer *t);

	/* warning: After calling this method the KIRCTransfer is removed from the m_idMap.
	 */
	KIRCTransfer *getKIRCTransfer(const KopeteFileTransferInfo &info);

	KIRCTransferHandler *handler();

	QIntDict<KIRCTransfer> m_idMap;
};

#endif

==> kdenetwork-3.5.10.tar.bz2: kdenetwork-3.5.10/kopete/protocols/irc/irctransferhandler.h <==
/*
    irctransferhandler.h - IRC transfer.

    Copyright (c) 2003      by Michel Hermier <michel.hermier@wanadoo.fr>

    Kopete    (c) 2003      by the Kopete developers <kopete-devel@kde.org>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef IRCTRANSFERHANDLER_H
#define IRCTRANSFERHANDLER_H

#include <qintdict.h>

#include <kopetetransfermanager.h>

namespace Kopete
{
	class Transfer;
}

namespace KIRC
{
class Transfer;
class TransferHandler;
}

class IRCTransferHandler
	: public QObject
{
	Q_OBJECT

public:
	static IRCTransferHandler *self();

private slots:
	void transferCreated(KIRC::Transfer *);
	void transferAccepted(Kopete::Transfer *kt, const QString&file);
	void transferRefused(const Kopete::FileTransferInfo &info);

	void kioresult(KIO::Job *job);

private:
	IRCTransferHandler();

	void connectKopeteTransfer(Kopete::Transfer *kt, KIRC::Transfer *t);

	/* warning: After calling this method the KIRC::Transfer is removed from the m_idMap.
	 */
	KIRC::Transfer *getKIRCTransfer(const Kopete::FileTransferInfo &info);

	KIRC::TransferHandler *handler();

	QIntDict<KIRC::Transfer> m_idMap;
};

#endif
